@@ -10,6 +10,7 @@ import (
 	"github.com/openshift/cluster-samples-operator/pkg/util"
 	"github.com/sirupsen/logrus"
 	corev1 "k8s.io/api/core/v1"
+	kerrors "k8s.io/apimachinery/pkg/api/errors"
 	kapis "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
@@ -17,6 +18,20 @@ func (h *Handler) ClearStatusConfigForRemoved(cfg *v1.Config) {
 	cfg.Status.Architectures = []string{}
 }
 
+func (h *Handler) IsValidArch(cfg *v1.Config) (bool, string) {
+	for _, arch := range cfg.Spec.Architectures {
+		switch arch {
+		case v1.X86Architecture:
+		case v1.AMDArchitecture:
+		case v1.PPCArchitecture:
+		case v1.S390Architecture:
+		default:
+			return false, arch
+		}
+	}
+	return true, ""
+}
+
 func (h *Handler) StoreCurrentValidConfig(cfg *v1.Config) {
 	cfg.Status.SamplesRegistry = cfg.Spec.SamplesRegistry
 	cfg.Status.Architectures = cfg.Spec.Architectures
@@ -28,16 +43,9 @@ func (h *Handler) SpecValidation(cfg *v1.Config) error {
 	// the first thing this should do is check that all the config values
 	// are "valid" (the architecture name is known, the distribution name is known, etc)
 	// if that fails, we should immediately error out and set ConfigValid to false.
-	for _, arch := range cfg.Spec.Architectures {
-		switch arch {
-		case v1.X86Architecture:
-		case v1.AMDArchitecture:
-		case v1.PPCArchitecture:
-		case v1.S390Architecture:
-		default:
-			err := fmt.Errorf("architecture %s unsupported; only support %s", arch, strings.Join([]string{v1.X86Architecture, v1.AMDArchitecture, v1.PPCArchitecture, v1.S390Architecture}, ","))
-			return h.processError(cfg, v1.ConfigurationValid, corev1.ConditionFalse, err, "%v")
-		}
+	if valid, badArch := h.IsValidArch(cfg); !valid {
+		err := fmt.Errorf("architecture %s unsupported; only support %s", badArch, strings.Join([]string{v1.X86Architecture, v1.AMDArchitecture, v1.PPCArchitecture, v1.S390Architecture}, ","))
+		return h.processError(cfg, v1.ConfigurationValid, corev1.ConditionFalse, err, "%v")
 	}
 
 	// only if the values being requested are valid, should we then proceed to check
@@ -231,6 +239,19 @@ func (h *Handler) processError(opcfg *v1.Config, ctype v1.ConfigConditionType, c
 		}
 		status.Status = cstatus
 		status.Message = log
+
+		// most reasons for degraded status are handled in ClusterOperatorStatusDegradedCondition based on
+		// state in the opcfg correlated with other factors; but when the error should directly drive the
+		// reason text, we set the reason here; at this time, that means either API Server errors or
+		// errors accessing the local file system
+		reason := kerrors.ReasonForError(err)
+		switch {
+		case len(reason) > 0 && reason != kapis.StatusReasonUnknown:
+			status.Reason = fmt.Sprintf("APIServer%sError", reason)
+		case cstatus == corev1.ConditionUnknown && ctype == v1.SamplesExist:
+			status.Reason = "FileSystemError"
+		}
+
 		util.ConditionUpdate(opcfg, status)
 	}
 
